PCB Environment: metrics Namespace Reference

PCB Environment 2

Loading...
Searching...
No Matches
Functions
metrics Namespace Reference

## Functions
Real | ConnectionLinkage (const Connection &, const Connection &, bool cross, Real ex=2.0, int log2StepSize=-3)
Real | ConnectionLinkage (const PCBoard &, Real ex, int log2StepSize)
uint | RatsNestCrossings (const PCBoard &)
void | SegmentParallelity (Real &cosine, Real &weight, const WideSegment_25 &, const WideSegment_25 &)

## Function Documentation

## ◆ ConnectionLinkage() [1/2]

Real metrics::ConnectionLinkage | ( | const Connection & | ,
|  | const Connection & | ,
|  | bool | cross,
|  | Real | ex = 2.0,
|  | int | log2StepSize = -3 )

## ◆ ConnectionLinkage() [2/2]

Real metrics::ConnectionLinkage | ( | const PCBoard & | ,
|  | Real | ex,
|  | int | log2StepSize )

## ◆ RatsNestCrossings()

uint metrics::RatsNestCrossings | ( | const PCBoard & |  | ) |

## ◆ SegmentParallelity()

void metrics::SegmentParallelity | ( | Real & | cosine,
|  | Real & | weight,
|  | const WideSegment_25 & | ,
|  | const WideSegment_25 & | )